.. _api.string:

===============
String literals
===============
.. currentmodule:: grammatica.grammar

Constructor
-----------
.. autosummary::
   :toctree: api/

   String

Attributes
----------

.. autosummary::
   :toctree: api/

   String.value

Rendering
---------

.. autosummary::
   :toctree: api/

   String.render
   String.as_string

Simplification
--------------

.. autosummary::
   :toctree: api/

   String.simplify

Utility
-----------------

.. autosummary::
   :toctree: api/

   String.copy
   String.equals

Metadata
--------

.. warning:: ``String.attrs_dict`` is considered experimental and may change without warning.

.. autosummary::
   :toctree: api/

   String.attrs_dict
